import numpy as np
import matplotlib.pyplot as plt
from batman import TransitParams
from stash import LightCurve
from astropy.constants import R_earth, R_sun
import astropy.units as u

# Load light curve generated by `fetch_series.py`

fig, ax = plt.subplots(2, 1, figsize=(4, 8), sharex=True)

times, fluxes = np.loadtxt('data/lc.txt', unpack=True)
lc = LightCurve(times, fluxes)

params = TransitParams()
params.rp = float(R_earth/R_sun)  # Radius ratio (planet/star)
params.inc = 89.9       # Orbital inclination
params.t0 = 0           # Midtransit time
params.u = [0.6, 0.2]   # Quadratic limb-darkening parameters
params.w = 90           # Argument of periastron -- leave this
params.ecc = 0          # Orbital eccentricity -- leave this
params.per = 365        # orbital period
params.limb_dark = 'quadratic'
params.a = float(1 * u.AU / R_sun) # Semimajor axis in units of [R_star]

# Fit transit model to light curve `lc`
best_fit_lc = lc.get_transit_model(params, 1e-6)

best_fit_lc.plot(color='r', label='model', ls='--', ax=ax[0])

lc.plot(label='stash', ax=ax[0])
ax[0].set_ylabel('Flux')

ax[1].plot(lc.times, 1e6*(lc.fluxes - best_fit_lc.fluxes))
ax[1].set(xlabel='Time [d]', ylabel='Residuals [ppm]')

ax[0].legend()
plt.show()

